import { RequiredParam } from "../../../core/query-utils/required-param";
import { WalletAddress } from "../../types";
import { UseQueryResult } from "@tanstack/react-query";
import type { SmartContract } from "@thirdweb-dev/sdk";
import type { BytesLike } from "ethers";
/** **********************/
/**       READ HOOKS    **/
/** **********************/
/**
 * Get all accounts
 *
 * @example
 * ```javascript
 * const { data: accounts, isLoading, error } = useAccounts(contract);
 * ```
 *
 * @param contract - Instance of a account factory contract
 * @returns Query result object that includes an array of all accounts with their associated admin
 * @twfeature AccountFactory
 * @smartWallet
 */
export declare function useAccounts(contract: RequiredParam<SmartContract>): UseQueryResult<string[]>;
/**
 * Get all accounts associated with the provided address
 *
 * @example
 * ```javascript
 * const { data: accountsForAddress, isLoading, error } = useAccountsForAddress(contract, "{{account_address}}");
 * ```
 *
 * @param contract - Instance of a account factory contract
 * @param address - The address to get associated accounts for
 * @returns Query result object that includes an array of all accounts associated with the address
 *
 * @twfeature AccountFactory
 * @smartWallet
 */
export declare function useAccountsForAddress(contract: RequiredParam<SmartContract>, address: RequiredParam<WalletAddress>): UseQueryResult<string[]>;
/**
 * Check if a account has been deployed for the given admin in the account factory contract
 *
 * @example
 * ```javascript
 * const { data: isAccountDeployed, isLoading, error } = useIsAccountDeployed(contract);
 * ```
 *
 * @param contract - Instance of a account factory contract
 * @returns A boolean indicating if a account has been deployed for the given admin
 * @twfeature AccountFactory
 * @smartWallet
 */
export declare function useIsAccountDeployed(contract: RequiredParam<SmartContract>, admin: RequiredParam<WalletAddress>, extraData?: BytesLike): UseQueryResult<boolean>;
/** **********************/
/**     WRITE HOOKS     **/
/** **********************/
/**
 * Create a account in the account factory contract
 *
 * @example
 * ```jsx
 * const Component = () => {
 *   const { contract } = useContract("{{contract_address}}");
 *   const {
 *     mutate: createAccount,
 *     isLoading,
 *     error,
 *   } = useCreateAccount(contract);
 *
 *   if (error) {
 *     console.error("failed to create account", error);
 *   }
 *
 *   return (
 *     <button
 *       disabled={isLoading}
 *       onClick={() => createAccount("0x...")}
 *     >
 *       Create Account
 *     </button>
 *   );
 * };
 * ```
 *
 * @param contract - Instance of a account factory contract
 * @returns A mutation object to create a account
 * @twfeature AccountFactory
 * @smartWallet
 */
export declare function useCreateAccount(contract: RequiredParam<SmartContract>): import("@tanstack/react-query").UseMutationResult<import("@thirdweb-dev/sdk").TransactionResultWithAddress, unknown, string, unknown>;
//# sourceMappingURL=account-factory.d.ts.map